@@ -32,8 +32,8 @@ class DummyDisambiguation(MorphologicalDisambiguator):
         list
             CorrectFsmParses list.
         """
-        correctFsmParses = []
-        for fsmParseList in fsmParses:
-            if fsmParseList.size() > 0:
-                correctFsmParses.append(fsmParseList.getFsmParse(randrange(fsmParseList.size())))
-        return correctFsmParses
+        correct_fsm_parses = []
+        for fsm_parse_list in fsmParses:
+            if fsm_parse_list.size() > 0:
+                correct_fsm_parses.append(fsm_parse_list.getFsmParse(randrange(fsm_parse_list.size())))
+        return correct_fsm_parses
