@@ -11,8 +11,8 @@ from MorphologicalDisambiguation.NaiveDisambiguation import NaiveDisambiguation
 
 class HmmDisambiguation(NaiveDisambiguation):
 
-    wordBiGramModel: NGram
-    igBiGramModel: NGram
+    word_bi_gram_model: NGram
+    ig_bi_gram_model: NGram
 
     def train(self, corpus: DisambiguationCorpus):
         """
@@ -32,29 +32,29 @@ class HmmDisambiguation(NaiveDisambiguation):
         igs1 = [None]
         words2 = [None, None]
         igs2 = [None, None]
-        self.wordUniGramModel = NGram(1)
-        self.igUniGramModel = NGram(1)
-        self.wordBiGramModel = NGram(2)
-        self.igBiGramModel = NGram(2)
+        self.word_uni_gram_model = NGram(1)
+        self.ig_uni_gram_model = NGram(1)
+        self.word_bi_gram_model = NGram(2)
+        self.ig_bi_gram_model = NGram(2)
         for sentence in corpus.sentences:
             for j in range(sentence.wordCount() - 1):
                 word = sentence.getWord(j)
-                nextWord = sentence.getWord(j + 1)
+                next_word = sentence.getWord(j + 1)
                 words2[0] = word.getParse().getWordWithPos()
                 words1[0] = words2[0]
-                words2[1] = nextWord.getParse().getWordWithPos()
-                self.wordUniGramModel.addNGram(words1)
-                self.wordBiGramModel.addNGram(words2)
-                for k in range(nextWord.getParse().size()):
+                words2[1] = next_word.getParse().getWordWithPos()
+                self.word_uni_gram_model.addNGram(words1)
+                self.word_bi_gram_model.addNGram(words2)
+                for k in range(next_word.getParse().size()):
                     igs2[0] = Word(word.getParse().getLastInflectionalGroup().__str__())
-                    igs2[1] = Word(nextWord.getParse().getInflectionalGroup(k).__str__())
-                    self.igBiGramModel.addNGram(igs2)
+                    igs2[1] = Word(next_word.getParse().getInflectionalGroup(k).__str__())
+                    self.ig_bi_gram_model.addNGram(igs2)
                     igs1[0] = igs2[1]
-                    self.igUniGramModel.addNGram(igs1)
-        self.wordUniGramModel.calculateNGramProbabilitiesSimple(LaplaceSmoothing())
-        self.igUniGramModel.calculateNGramProbabilitiesSimple(LaplaceSmoothing())
-        self.wordBiGramModel.calculateNGramProbabilitiesSimple(LaplaceSmoothing())
-        self.igBiGramModel.calculateNGramProbabilitiesSimple(LaplaceSmoothing())
+                    self.ig_uni_gram_model.addNGram(igs1)
+        self.word_uni_gram_model.calculateNGramProbabilitiesSimple(LaplaceSmoothing())
+        self.ig_uni_gram_model.calculateNGramProbabilitiesSimple(LaplaceSmoothing())
+        self.word_bi_gram_model.calculateNGramProbabilitiesSimple(LaplaceSmoothing())
+        self.ig_bi_gram_model.calculateNGramProbabilitiesSimple(LaplaceSmoothing())
 
     def disambiguate(self, fsmParses: list) -> list:
         """
@@ -78,66 +78,66 @@ class HmmDisambiguation(NaiveDisambiguation):
         for i in range(len(fsmParses)):
             if fsmParses[i].size() == 0:
                 return None
-        correctFsmParses = []
+        correct_fsm_parses = []
         probabilities = [[0.0 for _ in range(fsmParses[i].size())] for i in range(len(fsmParses))]
         best = [[0 for _ in range(fsmParses[i].size())] for i in range(len(fsmParses))]
         for i in range(fsmParses[0].size()):
-            currentParse = fsmParses[0].getFsmParse(i)
-            if isinstance(currentParse, FsmParse):
-                w1 = currentParse.getWordWithPos()
-                probability = self.wordUniGramModel.getProbability(w1)
-                for j in range(currentParse.size()):
-                    ig1 = Word(currentParse.getInflectionalGroup(j).__str__())
-                    probability *= self.igUniGramModel.getProbability(ig1)
+            current_parse = fsmParses[0].getFsmParse(i)
+            if isinstance(current_parse, FsmParse):
+                w1 = current_parse.getWordWithPos()
+                probability = self.word_uni_gram_model.getProbability(w1)
+                for j in range(current_parse.size()):
+                    ig1 = Word(current_parse.getInflectionalGroup(j).__str__())
+                    probability *= self.ig_uni_gram_model.getProbability(ig1)
                 probabilities[0][i] = math.log(probability)
         for i in range(1, len(fsmParses)):
             for j in range(fsmParses[i].size()):
-                bestProbability = -10000
-                bestIndex = -1
-                currentParse = fsmParses[i].getFsmParse(j)
-                if isinstance(currentParse, FsmParse):
+                best_probability = -10000
+                best_index = -1
+                current_parse = fsmParses[i].getFsmParse(j)
+                if isinstance(current_parse, FsmParse):
                     for k in range(fsmParses[i - 1].size()):
-                        previousParse = fsmParses[i - 1].getFsmParse(k)
-                        w1 = previousParse.getWordWithPos()
-                        w2 = currentParse.getWordWithPos()
-                        probability = probabilities[i - 1][k] + math.log(self.wordBiGramModel.getProbability(w1, w2))
+                        previous_parse = fsmParses[i - 1].getFsmParse(k)
+                        w1 = previous_parse.getWordWithPos()
+                        w2 = current_parse.getWordWithPos()
+                        probability = probabilities[i - 1][k] + math.log(self.word_bi_gram_model.getProbability(w1, w2))
                         for t in range(fsmParses[i].getFsmParse(j).size()):
-                            ig1 = Word(previousParse.lastInflectionalGroup().__str__())
-                            ig2 = Word(currentParse.getInflectionalGroup(t).__str__())
-                            probability += math.log(self.igBiGramModel.getProbability(ig1, ig2))
-                        if probability > bestProbability:
-                            bestIndex = k
-                            bestProbability = probability
-                probabilities[i][j] = bestProbability
-                best[i][j] = bestIndex
-        bestProbability = -10000
-        bestIndex = -1
+                            ig1 = Word(previous_parse.lastInflectionalGroup().__str__())
+                            ig2 = Word(current_parse.getInflectionalGroup(t).__str__())
+                            probability += math.log(self.ig_bi_gram_model.getProbability(ig1, ig2))
+                        if probability > best_probability:
+                            best_index = k
+                            best_probability = probability
+                probabilities[i][j] = best_probability
+                best[i][j] = best_index
+        best_probability = -10000
+        best_index = -1
         for i in range(fsmParses[len(fsmParses) - 1].size()):
-            if probabilities[len(fsmParses) - 1][i] > bestProbability:
-                bestProbability = probabilities[len(fsmParses) - 1][i]
-                bestIndex = i
-        if bestIndex == -1:
+            if probabilities[len(fsmParses) - 1][i] > best_probability:
+                best_probability = probabilities[len(fsmParses) - 1][i]
+                best_index = i
+        if best_index == -1:
             return None
-        correctFsmParses.append(fsmParses[len(fsmParses) - 1].getFsmParse(bestIndex))
+        correct_fsm_parses.append(fsmParses[len(fsmParses) - 1].getFsmParse(best_index))
         for i in range(len(fsmParses) - 2, -1, -1):
-            bestIndex = best[i + 1][bestIndex]
-            if bestIndex == -1:
+            best_index = best[i + 1][best_index]
+            if best_index == -1:
                 return None
-            correctFsmParses.insert(0, fsmParses[i].getFsmParse(bestIndex))
-        return correctFsmParses
+            correct_fsm_parses.insert(0, fsmParses[i].getFsmParse(best_index))
+        return correct_fsm_parses
 
     def saveModel(self):
         """
         Method to save unigrams and bigrams.
         """
         super().saveModel()
-        self.wordBiGramModel.saveAsText("words2.txt")
-        self.igBiGramModel.saveAsText("igs2.txt")
+        self.word_bi_gram_model.saveAsText("words2.txt")
+        self.ig_bi_gram_model.saveAsText("igs2.txt")
 
     def loadModel(self):
         """
         Method to load unigrams and bigrams.
         """
         super().loadModel()
-        self.wordBiGramModel = NGram("words2.txt")
-        self.igBiGramModel = NGram("igs2.txt")
+        self.word_bi_gram_model = NGram("words2.txt")
+        self.ig_bi_gram_model = NGram("igs2.txt")
