@@ -5,20 +5,20 @@ from MorphologicalDisambiguation.MorphologicalDisambiguator import Morphological
 
 class NaiveDisambiguation(MorphologicalDisambiguator):
 
-    wordUniGramModel: NGram
-    igUniGramModel: NGram
+    word_uni_gram_model: NGram
+    ig_uni_gram_model: NGram
 
     def saveModel(self):
         """
         The saveModel method writes the specified objects i.e wordUniGramModel and igUniGramModel to the
         words1.txt and igs1.txt.
         """
-        self.wordUniGramModel.saveAsText("words1.txt")
-        self.igUniGramModel.saveAsText("igs1.txt")
+        self.word_uni_gram_model.saveAsText("words1.txt")
+        self.ig_uni_gram_model.saveAsText("igs1.txt")
 
     def loadModel(self):
         """
         The loadModel method reads objects at the words1.txt and igs1.txt to the wordUniGramModel and igUniGramModel.
         """
-        self.wordUniGramModel = NGram("words1.txt")
-        self.igUniGramModel = NGram("igs1.txt")
+        self.word_uni_gram_model = NGram("words1.txt")
+        self.ig_uni_gram_model = NGram("igs1.txt")
